import { useMemo } from 'react';
/**
 * 获取目标元素相对于某个容器的缩放比率
 * @param containerSize 作为容器的元素尺寸
 * @param targetSize 作为内容的元素尺寸
 * @param keepSize 值为true时，如果容器宽高均大于内容元素，则返回1，即不放大
 * @returns
 */
export function useScale(containerSize, targetSize) {
  var keepSize = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  return useMemo(function () {
    if (containerSize && targetSize) {
      var elWidth = containerSize.width,
        elHeight = containerSize.height;
      var width = targetSize.width,
        height = targetSize.height;
      var r1 = width / height;
      var r2 = elWidth / elHeight;
      var scale = r2 > r1 ? elHeight / height : elWidth / width;
      if (keepSize && !(elWidth < width || elHeight < height)) {
        return 1;
      }
      return scale;
    }
    return -1;
  }, [containerSize, targetSize]);
}